@@ -7,17 +7,17 @@ from aiohttp.test_utils import TestServer as _TestServer
 
 
 @pytest.fixture
-def app(loop):
+def app():
     async def handler(request):
         return web.Response(body=b"OK")
 
-    app = web.Application(loop=loop)
+    app = web.Application()
     app.router.add_route('*', '/', handler)
     return app
 
 
 async def test_server_context_manager(app, loop):
-    async with _TestServer(app) as server:
+    async with _TestServer(app, loop=loop) as server:
         async with aiohttp.ClientSession(loop=loop) as client:
             async with client.head(server.make_url('/')) as resp:
                 assert resp.status == 200
@@ -27,7 +27,7 @@ async def test_server_context_manager(app, loop):
     "head", "get", "post", "options", "post", "put", "patch", "delete"
 ])
 async def test_client_context_manager_response(method, app, loop):
-    async with _TestClient(app) as client:
+    async with _TestClient(_TestServer(app), loop=loop) as client:
         async with getattr(client, method)('/') as resp:
             assert resp.status == 200
             if method != 'head':
